@@ -18,9 +18,57 @@
 
 #include "gva-preferences.h"
 
+#include "gva-column-manager.h"
 #include "gva-error.h"
+#include "gva-mame.h"
 #include "gva-ui.h"
-#include "gva-xmame.h"
+
+static void
+preferences_init_general (void)
+{
+        /* Auto Save */
+
+        gtk_action_connect_proxy (
+                GVA_ACTION_AUTO_SAVE,
+                GVA_WIDGET_PREFERENCES_AUTO_SAVE);
+
+        gtk_action_set_sensitive (
+                GVA_ACTION_AUTO_SAVE,
+                gva_mame_supports_auto_save ());
+
+        gtk_toggle_action_set_active (
+                GTK_TOGGLE_ACTION (GVA_ACTION_AUTO_SAVE),
+                gva_preferences_get_auto_save ());
+
+        /* Full Screen */
+
+        gtk_action_connect_proxy (
+                GVA_ACTION_FULL_SCREEN,
+                GVA_WIDGET_PREFERENCES_FULL_SCREEN);
+
+        gtk_action_set_sensitive (
+                GVA_ACTION_FULL_SCREEN,
+                gva_mame_supports_full_screen () ||
+                gva_mame_supports_window ());
+
+        gtk_toggle_action_set_active (
+                GTK_TOGGLE_ACTION (GVA_ACTION_FULL_SCREEN),
+                gva_preferences_get_full_screen ());
+}
+
+static void
+preferences_init_columns (void)
+{
+        GtkWidget *column_manager;
+        GtkTreeView *view;
+
+        view = GTK_TREE_VIEW (GVA_WIDGET_MAIN_TREE_VIEW);
+        column_manager = gva_column_manager_new (view);
+
+        gtk_box_pack_start (
+                GTK_BOX (GVA_WIDGET_PREFERENCES_COLUMNS_INNER_VBOX),
+                column_manager, TRUE, TRUE, 0);
+}
 
 void
 gva_preferences_init (void)
@@ -30,14 +78,6 @@ gva_preferences_init (void)
 
         window = GTK_WINDOW (GVA_WIDGET_PREFERENCES_WINDOW);
 
-        gtk_action_connect_proxy (
-                GVA_ACTION_AUTO_SAVE,
-                GVA_WIDGET_PREFERENCES_AUTO_SAVE);
-
-        gtk_action_connect_proxy (
-                GVA_ACTION_FULL_SCREEN,
-                GVA_WIDGET_PREFERENCES_FULL_SCREEN);
-
         g_signal_connect (
                 GVA_WIDGET_PREFERENCES_WINDOW, "delete-event",
                 G_CALLBACK (gtk_widget_hide_on_delete), NULL);
@@ -46,21 +86,8 @@ gva_preferences_init (void)
                 GVA_WIDGET_PREFERENCES_CLOSE_BUTTON, "clicked",
                 G_CALLBACK (gtk_widget_hide), window);
 
-        gtk_toggle_action_set_active (
-                GTK_TOGGLE_ACTION (GVA_ACTION_AUTO_SAVE),
-                gva_preferences_get_auto_save ());
-
-        gtk_action_set_sensitive (
-                GVA_ACTION_AUTO_SAVE,
-                gva_xmame_supports_auto_save ());
-
-        gtk_toggle_action_set_active (
-                GTK_TOGGLE_ACTION (GVA_ACTION_FULL_SCREEN),
-                gva_preferences_get_full_screen ());
-
-        gtk_action_set_sensitive (
-                GVA_ACTION_FULL_SCREEN,
-                gva_xmame_supports_full_screen ());
+        preferences_init_general ();
+        preferences_init_columns ();
 }
 
 gboolean
@@ -120,3 +147,4 @@ gva_preferences_set_full_screen (gboolean full_screen)
         gva_error_handle (&error);
         g_object_unref (client);
 }
+
